Struct aws_sdk_lambda::operation::create_code_signing_config::builders::CreateCodeSigningConfigInputBuilder
source · #[non_exhaustive]pub struct CreateCodeSigningConfigInputBuilder { /* private fields */ }Expand description
A builder for CreateCodeSigningConfigInput.
Implementations
sourceimpl CreateCodeSigningConfigInputBuilder
impl CreateCodeSigningConfigInputBuilder
sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
Descriptive name for this code signing configuration.
sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
Descriptive name for this code signing configuration.
sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
Descriptive name for this code signing configuration.
sourcepub fn allowed_publishers(self, input: AllowedPublishers) -> Self
pub fn allowed_publishers(self, input: AllowedPublishers) -> Self
Signing profiles for this code signing configuration.
This field is required.sourcepub fn set_allowed_publishers(self, input: Option<AllowedPublishers>) -> Self
pub fn set_allowed_publishers(self, input: Option<AllowedPublishers>) -> Self
Signing profiles for this code signing configuration.
sourcepub fn get_allowed_publishers(&self) -> &Option<AllowedPublishers>
pub fn get_allowed_publishers(&self) -> &Option<AllowedPublishers>
Signing profiles for this code signing configuration.
sourcepub fn code_signing_policies(self, input: CodeSigningPolicies) -> Self
pub fn code_signing_policies(self, input: CodeSigningPolicies) -> Self
The code signing policies define the actions to take if the validation checks fail.
sourcepub fn set_code_signing_policies(
self,
input: Option<CodeSigningPolicies>
) -> Self
pub fn set_code_signing_policies( self, input: Option<CodeSigningPolicies> ) -> Self
The code signing policies define the actions to take if the validation checks fail.
sourcepub fn get_code_signing_policies(&self) -> &Option<CodeSigningPolicies>
pub fn get_code_signing_policies(&self) -> &Option<CodeSigningPolicies>
The code signing policies define the actions to take if the validation checks fail.
sourcepub fn build(self) -> Result<CreateCodeSigningConfigInput, BuildError>
pub fn build(self) -> Result<CreateCodeSigningConfigInput, BuildError>
Consumes the builder and constructs a CreateCodeSigningConfigInput.
sourceimpl CreateCodeSigningConfigInputBuilder
impl CreateCodeSigningConfigInputBuilder
sourcepub async fn send_with(
self,
client: &Client
) -> Result<CreateCodeSigningConfigOutput, SdkError<CreateCodeSigningConfigError, HttpResponse>>
pub async fn send_with( self, client: &Client ) -> Result<CreateCodeSigningConfigOutput, SdkError<CreateCodeSigningConfigError, HttpResponse>>
Sends a request with this input using the given client.