Struct aws_sdk_lambda::operation::get_function_code_signing_config::builders::GetFunctionCodeSigningConfigInputBuilder
source · #[non_exhaustive]pub struct GetFunctionCodeSigningConfigInputBuilder { /* private fields */ }Expand description
A builder for GetFunctionCodeSigningConfigInput.
Implementations
sourceimpl GetFunctionCodeSigningConfigInputBuilder
impl GetFunctionCodeSigningConfigInputBuilder
sourcepub fn function_name(self, input: impl Into<String>) -> Self
pub fn function_name(self, input: impl Into<String>) -> Self
The name or ARN of the Lambda function.
Name formats
-
Function name -
MyFunction. -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:MyFunction. -
Partial ARN -
123456789012:function:MyFunction.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
This field is required.sourcepub fn set_function_name(self, input: Option<String>) -> Self
pub fn set_function_name(self, input: Option<String>) -> Self
The name or ARN of the Lambda function.
Name formats
-
Function name -
MyFunction. -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:MyFunction. -
Partial ARN -
123456789012:function:MyFunction.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
sourcepub fn get_function_name(&self) -> &Option<String>
pub fn get_function_name(&self) -> &Option<String>
The name or ARN of the Lambda function.
Name formats
-
Function name -
MyFunction. -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:MyFunction. -
Partial ARN -
123456789012:function:MyFunction.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
sourcepub fn build(self) -> Result<GetFunctionCodeSigningConfigInput, BuildError>
pub fn build(self) -> Result<GetFunctionCodeSigningConfigInput, BuildError>
Consumes the builder and constructs a GetFunctionCodeSigningConfigInput.
sourceimpl GetFunctionCodeSigningConfigInputBuilder
impl GetFunctionCodeSigningConfigInputBuilder
sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetFunctionCodeSigningConfigOutput, SdkError<GetFunctionCodeSigningConfigError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetFunctionCodeSigningConfigOutput, SdkError<GetFunctionCodeSigningConfigError, HttpResponse>>
Sends a request with this input using the given client.