#[non_exhaustive]pub enum InvokeAsyncError {
Show 30 variants
Ec2AccessDeniedException(Ec2AccessDeniedException),
Ec2ThrottledException(Ec2ThrottledException),
Ec2UnexpectedException(Ec2UnexpectedException),
EfsioException(EfsioException),
EfsMountConnectivityException(EfsMountConnectivityException),
EfsMountFailureException(EfsMountFailureException),
EfsMountTimeoutException(EfsMountTimeoutException),
EniLimitReachedException(EniLimitReachedException),
InvalidRequestContentException(InvalidRequestContentException),
InvalidRuntimeException(InvalidRuntimeException),
InvalidSecurityGroupIdException(InvalidSecurityGroupIdException),
InvalidSubnetIdException(InvalidSubnetIdException),
KmsAccessDeniedException(KmsAccessDeniedException),
KmsDisabledException(KmsDisabledException),
KmsInvalidStateException(KmsInvalidStateException),
KmsNotFoundException(KmsNotFoundException),
ModeNotSupportedException(ModeNotSupportedException),
ResourceConflictException(ResourceConflictException),
ResourceNotFoundException(ResourceNotFoundException),
S3FilesMountConnectivityException(S3FilesMountConnectivityException),
S3FilesMountFailureException(S3FilesMountFailureException),
S3FilesMountTimeoutException(S3FilesMountTimeoutException),
ServiceException(ServiceException),
ServiceQuotaExceededException(ServiceQuotaExceededException),
SnapStartException(SnapStartException),
SnapStartNotReadyException(SnapStartNotReadyException),
SnapStartRegenerationFailureException(SnapStartRegenerationFailureException),
SnapStartTimeoutException(SnapStartTimeoutException),
SubnetIpAddressLimitReachedException(SubnetIpAddressLimitReachedException),
Unhandled(Unhandled),
}Expand description
Error type for the InvokeAsyncError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Ec2AccessDeniedException(Ec2AccessDeniedException)
Need additional permissions to configure VPC settings.
Ec2ThrottledException(Ec2ThrottledException)
Amazon EC2 throttled Lambda during Lambda function initialization using the execution role provided for the function.
Ec2UnexpectedException(Ec2UnexpectedException)
Lambda received an unexpected Amazon EC2 client exception while setting up for the Lambda function.
EfsioException(EfsioException)
An error occurred when reading from or writing to a connected file system.
EfsMountConnectivityException(EfsMountConnectivityException)
The Lambda function couldn't make a network connection to the configured file system.
EfsMountFailureException(EfsMountFailureException)
The Lambda function couldn't mount the configured file system due to a permission or configuration issue.
EfsMountTimeoutException(EfsMountTimeoutException)
The Lambda function made a network connection to the configured file system, but the mount operation timed out.
EniLimitReachedException(EniLimitReachedException)
Lambda couldn't create an elastic network interface in the VPC, specified as part of Lambda function configuration, because the limit for network interfaces has been reached. For more information, see Lambda quotas.
InvalidRequestContentException(InvalidRequestContentException)
The request body could not be parsed as JSON, or a request header is invalid. For example, the 'x-amzn-RequestId' header is not a valid UUID string.
InvalidRuntimeException(InvalidRuntimeException)
The runtime or runtime version specified is not supported.
InvalidSecurityGroupIdException(InvalidSecurityGroupIdException)
The security group ID provided in the Lambda function VPC configuration is not valid.
InvalidSubnetIdException(InvalidSubnetIdException)
The subnet ID provided in the Lambda function VPC configuration is not valid.
KmsAccessDeniedException(KmsAccessDeniedException)
Lambda couldn't decrypt the environment variables because KMS access was denied. Check the Lambda function's KMS permissions.
KmsDisabledException(KmsDisabledException)
Lambda couldn't decrypt the environment variables because the KMS key used is disabled. Check the Lambda function's KMS key settings.
KmsInvalidStateException(KmsInvalidStateException)
Lambda couldn't decrypt the environment variables because the state of the KMS key used is not valid for Decrypt. Check the function's KMS key settings.
KmsNotFoundException(KmsNotFoundException)
Lambda couldn't decrypt the environment variables because the KMS key was not found. Check the function's KMS key settings.
ModeNotSupportedException(ModeNotSupportedException)
The Lambda function doesn't support the invocation mode requested. For example, calling Invoke with InvocationType=RequestResponse on a function configured for asynchronous-only invocation, or vice versa. For more information about invocation types, see Invoking Lambda functions.
ResourceConflictException(ResourceConflictException)
The resource already exists, or another operation is in progress.
ResourceNotFoundException(ResourceNotFoundException)
The resource specified in the request does not exist.
S3FilesMountConnectivityException(S3FilesMountConnectivityException)
The Lambda function couldn't make a network connection to the configured S3 Files access point.
S3FilesMountFailureException(S3FilesMountFailureException)
The Lambda function couldn't mount the configured S3 Files access point due to a permission or configuration issue.
S3FilesMountTimeoutException(S3FilesMountTimeoutException)
The Lambda function made a network connection to the configured S3 Files access point, but the mount operation timed out.
ServiceException(ServiceException)
The Lambda service encountered an internal error.
ServiceQuotaExceededException(ServiceQuotaExceededException)
The request would exceed a service quota. For more information about Lambda service quotas, see Lambda quotas. To request a quota increase, see Requesting a quota increase in the Service Quotas User Guide.
SnapStartException(SnapStartException)
The afterRestore() runtime hook encountered an error. For more information, check the Amazon CloudWatch logs.
SnapStartNotReadyException(SnapStartNotReadyException)
Lambda is initializing your function. You can invoke the function when the function state becomes Active.
SnapStartRegenerationFailureException(SnapStartRegenerationFailureException)
Lambda couldn't regenerate the SnapStart snapshot for the function. SnapStart-enabled functions periodically regenerate snapshots when their underlying runtime or dependencies change; this regeneration failed. Wait for Lambda to retry, or update the function's configuration to trigger a new snapshot. For more information, see Lambda SnapStart.
SnapStartTimeoutException(SnapStartTimeoutException)
Lambda couldn't restore the snapshot within the timeout limit.
SubnetIpAddressLimitReachedException(SubnetIpAddressLimitReachedException)
Lambda couldn't set up VPC access for the Lambda function because one or more configured subnets has no available IP addresses.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl InvokeAsyncError
impl InvokeAsyncError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the InvokeAsyncError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the InvokeAsyncError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_ec2_access_denied_exception(&self) -> bool
pub fn is_ec2_access_denied_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::Ec2AccessDeniedException.
Sourcepub fn is_ec2_throttled_exception(&self) -> bool
pub fn is_ec2_throttled_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::Ec2ThrottledException.
Sourcepub fn is_ec2_unexpected_exception(&self) -> bool
pub fn is_ec2_unexpected_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::Ec2UnexpectedException.
Sourcepub fn is_efsio_exception(&self) -> bool
pub fn is_efsio_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::EfsioException.
Sourcepub fn is_efs_mount_connectivity_exception(&self) -> bool
pub fn is_efs_mount_connectivity_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::EfsMountConnectivityException.
Sourcepub fn is_efs_mount_failure_exception(&self) -> bool
pub fn is_efs_mount_failure_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::EfsMountFailureException.
Sourcepub fn is_efs_mount_timeout_exception(&self) -> bool
pub fn is_efs_mount_timeout_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::EfsMountTimeoutException.
Sourcepub fn is_eni_limit_reached_exception(&self) -> bool
pub fn is_eni_limit_reached_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::EniLimitReachedException.
Sourcepub fn is_invalid_request_content_exception(&self) -> bool
pub fn is_invalid_request_content_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::InvalidRequestContentException.
Sourcepub fn is_invalid_runtime_exception(&self) -> bool
pub fn is_invalid_runtime_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::InvalidRuntimeException.
Sourcepub fn is_invalid_security_group_id_exception(&self) -> bool
pub fn is_invalid_security_group_id_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::InvalidSecurityGroupIdException.
Sourcepub fn is_invalid_subnet_id_exception(&self) -> bool
pub fn is_invalid_subnet_id_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::InvalidSubnetIdException.
Sourcepub fn is_kms_access_denied_exception(&self) -> bool
pub fn is_kms_access_denied_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::KmsAccessDeniedException.
Sourcepub fn is_kms_disabled_exception(&self) -> bool
pub fn is_kms_disabled_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::KmsDisabledException.
Sourcepub fn is_kms_invalid_state_exception(&self) -> bool
pub fn is_kms_invalid_state_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::KmsInvalidStateException.
Sourcepub fn is_kms_not_found_exception(&self) -> bool
pub fn is_kms_not_found_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::KmsNotFoundException.
Sourcepub fn is_mode_not_supported_exception(&self) -> bool
pub fn is_mode_not_supported_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::ModeNotSupportedException.
Sourcepub fn is_resource_conflict_exception(&self) -> bool
pub fn is_resource_conflict_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::ResourceConflictException.
Sourcepub fn is_resource_not_found_exception(&self) -> bool
pub fn is_resource_not_found_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::ResourceNotFoundException.
Sourcepub fn is_s3_files_mount_connectivity_exception(&self) -> bool
pub fn is_s3_files_mount_connectivity_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::S3FilesMountConnectivityException.
Sourcepub fn is_s3_files_mount_failure_exception(&self) -> bool
pub fn is_s3_files_mount_failure_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::S3FilesMountFailureException.
Sourcepub fn is_s3_files_mount_timeout_exception(&self) -> bool
pub fn is_s3_files_mount_timeout_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::S3FilesMountTimeoutException.
Sourcepub fn is_service_exception(&self) -> bool
pub fn is_service_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::ServiceException.
Sourcepub fn is_service_quota_exceeded_exception(&self) -> bool
pub fn is_service_quota_exceeded_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::ServiceQuotaExceededException.
Sourcepub fn is_snap_start_exception(&self) -> bool
pub fn is_snap_start_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::SnapStartException.
Sourcepub fn is_snap_start_not_ready_exception(&self) -> bool
pub fn is_snap_start_not_ready_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::SnapStartNotReadyException.
Sourcepub fn is_snap_start_regeneration_failure_exception(&self) -> bool
pub fn is_snap_start_regeneration_failure_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::SnapStartRegenerationFailureException.
Sourcepub fn is_snap_start_timeout_exception(&self) -> bool
pub fn is_snap_start_timeout_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::SnapStartTimeoutException.
Sourcepub fn is_subnet_ip_address_limit_reached_exception(&self) -> bool
pub fn is_subnet_ip_address_limit_reached_exception(&self) -> bool
Returns true if the error kind is InvokeAsyncError::SubnetIpAddressLimitReachedException.