Struct aws_sdk_lambda::operation::put_function_code_signing_config::builders::PutFunctionCodeSigningConfigOutputBuilder
source · #[non_exhaustive]pub struct PutFunctionCodeSigningConfigOutputBuilder { /* private fields */ }Expand description
A builder for PutFunctionCodeSigningConfigOutput.
Implementations
sourceimpl PutFunctionCodeSigningConfigOutputBuilder
impl PutFunctionCodeSigningConfigOutputBuilder
sourcepub fn code_signing_config_arn(self, input: impl Into<String>) -> Self
pub fn code_signing_config_arn(self, input: impl Into<String>) -> Self
The The Amazon Resource Name (ARN) of the code signing configuration.
This field is required.sourcepub fn set_code_signing_config_arn(self, input: Option<String>) -> Self
pub fn set_code_signing_config_arn(self, input: Option<String>) -> Self
The The Amazon Resource Name (ARN) of the code signing configuration.
sourcepub fn get_code_signing_config_arn(&self) -> &Option<String>
pub fn get_code_signing_config_arn(&self) -> &Option<String>
The The Amazon Resource Name (ARN) of the code signing configuration.
sourcepub fn function_name(self, input: impl Into<String>) -> Self
pub fn function_name(self, input: impl Into<String>) -> Self
The name or ARN of the Lambda function.
Name formats
-
Function name -
MyFunction. -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:MyFunction. -
Partial ARN -
123456789012:function:MyFunction.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
This field is required.sourcepub fn set_function_name(self, input: Option<String>) -> Self
pub fn set_function_name(self, input: Option<String>) -> Self
The name or ARN of the Lambda function.
Name formats
-
Function name -
MyFunction. -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:MyFunction. -
Partial ARN -
123456789012:function:MyFunction.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
sourcepub fn get_function_name(&self) -> &Option<String>
pub fn get_function_name(&self) -> &Option<String>
The name or ARN of the Lambda function.
Name formats
-
Function name -
MyFunction. -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:MyFunction. -
Partial ARN -
123456789012:function:MyFunction.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
sourcepub fn build(self) -> Result<PutFunctionCodeSigningConfigOutput, BuildError>
pub fn build(self) -> Result<PutFunctionCodeSigningConfigOutput, BuildError>
Consumes the builder and constructs a PutFunctionCodeSigningConfigOutput.
This method will fail if any of the following fields are not set: