Struct aws_sdk_lambda::operation::put_function_code_signing_config::PutFunctionCodeSigningConfigInput
source · #[non_exhaustive]pub struct PutFunctionCodeSigningConfigInput {
pub code_signing_config_arn: Option<String>,
pub function_name: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.code_signing_config_arn: Option<String>The The Amazon Resource Name (ARN) of the code signing configuration.
function_name: Option<String>The name or ARN of the Lambda function.
Name formats
-
Function name -
MyFunction. -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:MyFunction. -
Partial ARN -
123456789012:function:MyFunction.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
Implementations
sourceimpl PutFunctionCodeSigningConfigInput
impl PutFunctionCodeSigningConfigInput
sourcepub fn code_signing_config_arn(&self) -> Option<&str>
pub fn code_signing_config_arn(&self) -> Option<&str>
The The Amazon Resource Name (ARN) of the code signing configuration.
sourcepub fn function_name(&self) -> Option<&str>
pub fn function_name(&self) -> Option<&str>
The name or ARN of the Lambda function.
Name formats
-
Function name -
MyFunction. -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:MyFunction. -
Partial ARN -
123456789012:function:MyFunction.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
sourceimpl PutFunctionCodeSigningConfigInput
impl PutFunctionCodeSigningConfigInput
sourcepub fn builder() -> PutFunctionCodeSigningConfigInputBuilder
pub fn builder() -> PutFunctionCodeSigningConfigInputBuilder
Creates a new builder-style object to manufacture PutFunctionCodeSigningConfigInput.