Struct aws_sdk_lambda::operation::put_public_access_block_config::builders::PutPublicAccessBlockConfigInputBuilder
source · #[non_exhaustive]pub struct PutPublicAccessBlockConfigInputBuilder { /* private fields */ }Expand description
A builder for PutPublicAccessBlockConfigInput.
Implementations
sourceimpl PutPublicAccessBlockConfigInputBuilder
impl PutPublicAccessBlockConfigInputBuilder
sourcepub fn resource_arn(self, input: impl Into<String>) -> Self
pub fn resource_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the function you want to configure public-access settings for. Public-access settings are applied at the function level, so you can't apply different settings to function versions or aliases.
This field is required.sourcepub fn set_resource_arn(self, input: Option<String>) -> Self
pub fn set_resource_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the function you want to configure public-access settings for. Public-access settings are applied at the function level, so you can't apply different settings to function versions or aliases.
sourcepub fn get_resource_arn(&self) -> &Option<String>
pub fn get_resource_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the function you want to configure public-access settings for. Public-access settings are applied at the function level, so you can't apply different settings to function versions or aliases.
sourcepub fn public_access_block_config(self, input: PublicAccessBlockConfig) -> Self
pub fn public_access_block_config(self, input: PublicAccessBlockConfig) -> Self
An object defining the public-access settings you want to apply.
To block the creation of resource-based policies that would grant public access to your function, set BlockPublicPolicy to true. To allow the creation of resource-based policies that would grant public access to your function, set BlockPublicPolicy to false.
To block public access to your function, even if its resource-based policy allows it, set RestrictPublicResource to true. To allow public access to a function with a resource-based policy that permits it, set RestrictPublicResource to false.
The default setting for both BlockPublicPolicy and RestrictPublicResource is true.
sourcepub fn set_public_access_block_config(
self,
input: Option<PublicAccessBlockConfig>,
) -> Self
pub fn set_public_access_block_config( self, input: Option<PublicAccessBlockConfig>, ) -> Self
An object defining the public-access settings you want to apply.
To block the creation of resource-based policies that would grant public access to your function, set BlockPublicPolicy to true. To allow the creation of resource-based policies that would grant public access to your function, set BlockPublicPolicy to false.
To block public access to your function, even if its resource-based policy allows it, set RestrictPublicResource to true. To allow public access to a function with a resource-based policy that permits it, set RestrictPublicResource to false.
The default setting for both BlockPublicPolicy and RestrictPublicResource is true.
sourcepub fn get_public_access_block_config(&self) -> &Option<PublicAccessBlockConfig>
pub fn get_public_access_block_config(&self) -> &Option<PublicAccessBlockConfig>
An object defining the public-access settings you want to apply.
To block the creation of resource-based policies that would grant public access to your function, set BlockPublicPolicy to true. To allow the creation of resource-based policies that would grant public access to your function, set BlockPublicPolicy to false.
To block public access to your function, even if its resource-based policy allows it, set RestrictPublicResource to true. To allow public access to a function with a resource-based policy that permits it, set RestrictPublicResource to false.
The default setting for both BlockPublicPolicy and RestrictPublicResource is true.
sourcepub fn build(self) -> Result<PutPublicAccessBlockConfigInput, BuildError>
pub fn build(self) -> Result<PutPublicAccessBlockConfigInput, BuildError>
Consumes the builder and constructs a PutPublicAccessBlockConfigInput.
sourceimpl PutPublicAccessBlockConfigInputBuilder
impl PutPublicAccessBlockConfigInputBuilder
sourcepub async fn send_with(
self,
client: &Client,
) -> Result<PutPublicAccessBlockConfigOutput, SdkError<PutPublicAccessBlockConfigError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<PutPublicAccessBlockConfigOutput, SdkError<PutPublicAccessBlockConfigError, HttpResponse>>
Sends a request with this input using the given client.