Struct aws_sdk_lambda::operation::put_resource_policy::builders::PutResourcePolicyFluentBuilder
source · pub struct PutResourcePolicyFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to PutResourcePolicy.
Adds a resource-based policy to a function. You can use resource-based policies to grant access to other Amazon Web Services accounts, organizations, or services. Resource-based policies apply to a single function, version, or alias.
Adding a resource-based policy using this API action replaces any existing policy you've previously created. This means that if you've previously added resource-based permissions to a function using the AddPermission action, those permissions will be overwritten by your new policy.
Implementations
sourceimpl PutResourcePolicyFluentBuilder
impl PutResourcePolicyFluentBuilder
sourcepub fn as_input(&self) -> &PutResourcePolicyInputBuilder
pub fn as_input(&self) -> &PutResourcePolicyInputBuilder
Access the PutResourcePolicy as a reference.
sourcepub async fn send(
self,
) -> Result<PutResourcePolicyOutput, SdkError<PutResourcePolicyError, HttpResponse>>
pub async fn send( self, ) -> Result<PutResourcePolicyOutput, SdkError<PutResourcePolicyError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
sourcepub fn customize(
self,
) -> CustomizableOperation<PutResourcePolicyOutput, PutResourcePolicyError, Self>
pub fn customize( self, ) -> CustomizableOperation<PutResourcePolicyOutput, PutResourcePolicyError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
sourcepub fn resource_arn(self, input: impl Into<String>) -> Self
pub fn resource_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the function you want to add the policy to. You can use either a qualified or an unqualified ARN, but the value you specify must be a complete ARN and wildcard characters are not accepted.
sourcepub fn set_resource_arn(self, input: Option<String>) -> Self
pub fn set_resource_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the function you want to add the policy to. You can use either a qualified or an unqualified ARN, but the value you specify must be a complete ARN and wildcard characters are not accepted.
sourcepub fn get_resource_arn(&self) -> &Option<String>
pub fn get_resource_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the function you want to add the policy to. You can use either a qualified or an unqualified ARN, but the value you specify must be a complete ARN and wildcard characters are not accepted.
sourcepub fn policy(self, input: impl Into<String>) -> Self
pub fn policy(self, input: impl Into<String>) -> Self
The JSON resource-based policy you want to add to your function.
To learn more about creating resource-based policies for controlling access to Lambda, see Working with resource-based IAM policies in Lambda in the Lambda Developer Guide.
sourcepub fn set_policy(self, input: Option<String>) -> Self
pub fn set_policy(self, input: Option<String>) -> Self
The JSON resource-based policy you want to add to your function.
To learn more about creating resource-based policies for controlling access to Lambda, see Working with resource-based IAM policies in Lambda in the Lambda Developer Guide.
sourcepub fn get_policy(&self) -> &Option<String>
pub fn get_policy(&self) -> &Option<String>
The JSON resource-based policy you want to add to your function.
To learn more about creating resource-based policies for controlling access to Lambda, see Working with resource-based IAM policies in Lambda in the Lambda Developer Guide.
sourcepub fn revision_id(self, input: impl Into<String>) -> Self
pub fn revision_id(self, input: impl Into<String>) -> Self
Replace the existing policy only if its revision ID matches the string you specify. To find the revision ID of the policy currently attached to your function, use the GetResourcePolicy action.
sourcepub fn set_revision_id(self, input: Option<String>) -> Self
pub fn set_revision_id(self, input: Option<String>) -> Self
Replace the existing policy only if its revision ID matches the string you specify. To find the revision ID of the policy currently attached to your function, use the GetResourcePolicy action.
sourcepub fn get_revision_id(&self) -> &Option<String>
pub fn get_revision_id(&self) -> &Option<String>
Replace the existing policy only if its revision ID matches the string you specify. To find the revision ID of the policy currently attached to your function, use the GetResourcePolicy action.