pub struct Builder { /* private fields */ }Expand description
A builder for GetRuntimeManagementConfigOutput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn update_runtime_on(self, input: UpdateRuntimeOn) -> Self
pub fn update_runtime_on(self, input: UpdateRuntimeOn) -> Self
The current runtime update mode of the function.
sourcepub fn set_update_runtime_on(self, input: Option<UpdateRuntimeOn>) -> Self
pub fn set_update_runtime_on(self, input: Option<UpdateRuntimeOn>) -> Self
The current runtime update mode of the function.
sourcepub fn runtime_version_arn(self, input: impl Into<String>) -> Self
pub fn runtime_version_arn(self, input: impl Into<String>) -> Self
The ARN of the runtime the function is configured to use. If the runtime update mode is Manual, the ARN is returned, otherwise null is returned.
sourcepub fn set_runtime_version_arn(self, input: Option<String>) -> Self
pub fn set_runtime_version_arn(self, input: Option<String>) -> Self
The ARN of the runtime the function is configured to use. If the runtime update mode is Manual, the ARN is returned, otherwise null is returned.
sourcepub fn build(self) -> GetRuntimeManagementConfigOutput
pub fn build(self) -> GetRuntimeManagementConfigOutput
Consumes the builder and constructs a GetRuntimeManagementConfigOutput.