Struct aws_sdk_lambda::types::builders::CodeSigningPoliciesBuilder
source · #[non_exhaustive]pub struct CodeSigningPoliciesBuilder { /* private fields */ }Expand description
A builder for CodeSigningPolicies.
Implementations
sourceimpl CodeSigningPoliciesBuilder
impl CodeSigningPoliciesBuilder
sourcepub fn untrusted_artifact_on_deployment(self, input: CodeSigningPolicy) -> Self
pub fn untrusted_artifact_on_deployment(self, input: CodeSigningPolicy) -> Self
Code signing configuration policy for deployment validation failure. If you set the policy to Enforce, Lambda blocks the deployment request if signature validation checks fail. If you set the policy to Warn, Lambda allows the deployment and creates a CloudWatch log.
Default value: Warn
sourcepub fn set_untrusted_artifact_on_deployment(
self,
input: Option<CodeSigningPolicy>,
) -> Self
pub fn set_untrusted_artifact_on_deployment( self, input: Option<CodeSigningPolicy>, ) -> Self
Code signing configuration policy for deployment validation failure. If you set the policy to Enforce, Lambda blocks the deployment request if signature validation checks fail. If you set the policy to Warn, Lambda allows the deployment and creates a CloudWatch log.
Default value: Warn
sourcepub fn get_untrusted_artifact_on_deployment(&self) -> &Option<CodeSigningPolicy>
pub fn get_untrusted_artifact_on_deployment(&self) -> &Option<CodeSigningPolicy>
Code signing configuration policy for deployment validation failure. If you set the policy to Enforce, Lambda blocks the deployment request if signature validation checks fail. If you set the policy to Warn, Lambda allows the deployment and creates a CloudWatch log.
Default value: Warn
sourcepub fn build(self) -> CodeSigningPolicies
pub fn build(self) -> CodeSigningPolicies
Consumes the builder and constructs a CodeSigningPolicies.