#[non_exhaustive]pub struct S3FilesConfigBuilder { /* private fields */ }Expand description
A builder for S3FilesConfig.
Implementations
Sourceimpl S3FilesConfigBuilder
impl S3FilesConfigBuilder
Sourcepub fn direct_s3_read(self, input: DirectS3Read) -> Self
pub fn direct_s3_read(self, input: DirectS3Read) -> Self
Specifies if a function reads from the file system for the lowest latency, or through Amazon S3 Files feature "direct Amazon S3 bucket reads" for the highest throughput. Valid values:
-
AUTO(default) – Direct reads are active for functions you configure with 512 MB or more of memory. -
ENABLED– Enforces all reads are directly from the Amazon S3 bucket, regardless of available memory (less than 512 MB). -
DISABLED– Routes all reads through the file system, regardless of memory configuration.
To use direct reads, you must grant the execution role the s3:GetObject and s3:GetObjectVersion permissions. If a direct read fails, Lambda automatically falls back to reading through the file system.
Sourcepub fn set_direct_s3_read(self, input: Option<DirectS3Read>) -> Self
pub fn set_direct_s3_read(self, input: Option<DirectS3Read>) -> Self
Specifies if a function reads from the file system for the lowest latency, or through Amazon S3 Files feature "direct Amazon S3 bucket reads" for the highest throughput. Valid values:
-
AUTO(default) – Direct reads are active for functions you configure with 512 MB or more of memory. -
ENABLED– Enforces all reads are directly from the Amazon S3 bucket, regardless of available memory (less than 512 MB). -
DISABLED– Routes all reads through the file system, regardless of memory configuration.
To use direct reads, you must grant the execution role the s3:GetObject and s3:GetObjectVersion permissions. If a direct read fails, Lambda automatically falls back to reading through the file system.
Sourcepub fn get_direct_s3_read(&self) -> &Option<DirectS3Read>
pub fn get_direct_s3_read(&self) -> &Option<DirectS3Read>
Specifies if a function reads from the file system for the lowest latency, or through Amazon S3 Files feature "direct Amazon S3 bucket reads" for the highest throughput. Valid values:
-
AUTO(default) – Direct reads are active for functions you configure with 512 MB or more of memory. -
ENABLED– Enforces all reads are directly from the Amazon S3 bucket, regardless of available memory (less than 512 MB). -
DISABLED– Routes all reads through the file system, regardless of memory configuration.
To use direct reads, you must grant the execution role the s3:GetObject and s3:GetObjectVersion permissions. If a direct read fails, Lambda automatically falls back to reading through the file system.
Sourcepub fn build(self) -> S3FilesConfig
pub fn build(self) -> S3FilesConfig
Consumes the builder and constructs a S3FilesConfig.