Struct aws_sdk_lambda::types::error::EfsMountTimeoutException
source · #[non_exhaustive]pub struct EfsMountTimeoutException {
pub type: Option<String>,
pub message: Option<String>,
/* private fields */
}Expand description
The Lambda function made a network connection to the configured file system, but the mount operation timed out.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type: Option<String>message: Option<String>Implementations
sourceimpl EfsMountTimeoutException
impl EfsMountTimeoutException
sourcepub fn builder() -> EfsMountTimeoutExceptionBuilder
pub fn builder() -> EfsMountTimeoutExceptionBuilder
Creates a new builder-style object to manufacture EfsMountTimeoutException.