#[non_exhaustive]pub struct CapacityProviderLoggingConfig {
pub system_log_level: Option<SystemLogLevel>,
pub log_group: Option<String>,
}Expand description
The capacity provider's Amazon CloudWatch Logs configuration settings.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.system_log_level: Option<SystemLogLevel>Set this property to filter the system logs for your capacity provider that Lambda sends to CloudWatch. Lambda only sends system logs at the selected level of detail and lower, where DEBUG is the highest level and WARN is the lowest.
log_group: Option<String>The name of the Amazon CloudWatch log group the capacity provider sends logs to. By default, Lambda capacity providers send logs to a default log group named /aws/lambda/capacity-provider/<capacity provider name>. To use a different log group, enter an existing log group or enter a new log group name.
Implementations
Sourceimpl CapacityProviderLoggingConfig
impl CapacityProviderLoggingConfig
Sourcepub fn system_log_level(&self) -> Option<&SystemLogLevel>
pub fn system_log_level(&self) -> Option<&SystemLogLevel>
Set this property to filter the system logs for your capacity provider that Lambda sends to CloudWatch. Lambda only sends system logs at the selected level of detail and lower, where DEBUG is the highest level and WARN is the lowest.
Sourcepub fn log_group(&self) -> Option<&str>
pub fn log_group(&self) -> Option<&str>
The name of the Amazon CloudWatch log group the capacity provider sends logs to. By default, Lambda capacity providers send logs to a default log group named /aws/lambda/capacity-provider/<capacity provider name>. To use a different log group, enter an existing log group or enter a new log group name.
Sourceimpl CapacityProviderLoggingConfig
impl CapacityProviderLoggingConfig
Sourcepub fn builder() -> CapacityProviderLoggingConfigBuilder
pub fn builder() -> CapacityProviderLoggingConfigBuilder
Creates a new builder-style object to manufacture CapacityProviderLoggingConfig.