Struct aws_sdk_lambda::types::CodeSigningConfig
source · #[non_exhaustive]pub struct CodeSigningConfig {
pub code_signing_config_id: String,
pub code_signing_config_arn: String,
pub description: Option<String>,
pub allowed_publishers: Option<AllowedPublishers>,
pub code_signing_policies: Option<CodeSigningPolicies>,
pub last_modified: String,
}Expand description
Details about a Code signing configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.code_signing_config_id: StringUnique identifer for the Code signing configuration.
code_signing_config_arn: StringThe Amazon Resource Name (ARN) of the Code signing configuration.
description: Option<String>Code signing configuration description.
allowed_publishers: Option<AllowedPublishers>List of allowed publishers.
code_signing_policies: Option<CodeSigningPolicies>The code signing policy controls the validation failure action for signature mismatch or expiry.
last_modified: StringThe date and time that the Code signing configuration was last modified, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
Implementations
sourceimpl CodeSigningConfig
impl CodeSigningConfig
sourcepub fn code_signing_config_id(&self) -> &str
pub fn code_signing_config_id(&self) -> &str
Unique identifer for the Code signing configuration.
sourcepub fn code_signing_config_arn(&self) -> &str
pub fn code_signing_config_arn(&self) -> &str
The Amazon Resource Name (ARN) of the Code signing configuration.
sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
Code signing configuration description.
sourcepub fn allowed_publishers(&self) -> Option<&AllowedPublishers>
pub fn allowed_publishers(&self) -> Option<&AllowedPublishers>
List of allowed publishers.
sourcepub fn code_signing_policies(&self) -> Option<&CodeSigningPolicies>
pub fn code_signing_policies(&self) -> Option<&CodeSigningPolicies>
The code signing policy controls the validation failure action for signature mismatch or expiry.
sourcepub fn last_modified(&self) -> &str
pub fn last_modified(&self) -> &str
The date and time that the Code signing configuration was last modified, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
sourceimpl CodeSigningConfig
impl CodeSigningConfig
sourcepub fn builder() -> CodeSigningConfigBuilder
pub fn builder() -> CodeSigningConfigBuilder
Creates a new builder-style object to manufacture CodeSigningConfig.