Struct aws_sdk_lambda::types::CodeSigningPolicies
source · #[non_exhaustive]pub struct CodeSigningPolicies {
pub untrusted_artifact_on_deployment: Option<CodeSigningPolicy>,
}Expand description
Code signing configuration policies specify the validation failure action for signature mismatch or expiry.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.untrusted_artifact_on_deployment: Option<CodeSigningPolicy>Code signing configuration policy for deployment validation failure. If you set the policy to Enforce, Lambda blocks the deployment request if signature validation checks fail. If you set the policy to Warn, Lambda allows the deployment and creates a CloudWatch log.
Default value: Warn
Implementations
sourceimpl CodeSigningPolicies
impl CodeSigningPolicies
sourcepub fn untrusted_artifact_on_deployment(&self) -> Option<&CodeSigningPolicy>
pub fn untrusted_artifact_on_deployment(&self) -> Option<&CodeSigningPolicy>
Code signing configuration policy for deployment validation failure. If you set the policy to Enforce, Lambda blocks the deployment request if signature validation checks fail. If you set the policy to Warn, Lambda allows the deployment and creates a CloudWatch log.
Default value: Warn
sourceimpl CodeSigningPolicies
impl CodeSigningPolicies
sourcepub fn builder() -> CodeSigningPoliciesBuilder
pub fn builder() -> CodeSigningPoliciesBuilder
Creates a new builder-style object to manufacture CodeSigningPolicies.