#[non_exhaustive]pub struct S3FilesConfig {
pub direct_s3_read: Option<DirectS3Read>,
}Expand description
Setting controls how your function accesses data from an Amazon S3 file system.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.direct_s3_read: Option<DirectS3Read>Specifies if a function reads from the file system for the lowest latency, or through Amazon S3 Files feature "direct Amazon S3 bucket reads" for the highest throughput. Valid values:
-
AUTO(default) – Direct reads are active for functions you configure with 512 MB or more of memory. -
ENABLED– Enforces all reads are directly from the Amazon S3 bucket, regardless of available memory (less than 512 MB). -
DISABLED– Routes all reads through the file system, regardless of memory configuration.
To use direct reads, you must grant the execution role the s3:GetObject and s3:GetObjectVersion permissions. If a direct read fails, Lambda automatically falls back to reading through the file system.
Implementations
Sourceimpl S3FilesConfig
impl S3FilesConfig
Sourcepub fn direct_s3_read(&self) -> Option<&DirectS3Read>
pub fn direct_s3_read(&self) -> Option<&DirectS3Read>
Specifies if a function reads from the file system for the lowest latency, or through Amazon S3 Files feature "direct Amazon S3 bucket reads" for the highest throughput. Valid values:
-
AUTO(default) – Direct reads are active for functions you configure with 512 MB or more of memory. -
ENABLED– Enforces all reads are directly from the Amazon S3 bucket, regardless of available memory (less than 512 MB). -
DISABLED– Routes all reads through the file system, regardless of memory configuration.
To use direct reads, you must grant the execution role the s3:GetObject and s3:GetObjectVersion permissions. If a direct read fails, Lambda automatically falls back to reading through the file system.
Sourceimpl S3FilesConfig
impl S3FilesConfig
Sourcepub fn builder() -> S3FilesConfigBuilder
pub fn builder() -> S3FilesConfigBuilder
Creates a new builder-style object to manufacture S3FilesConfig.