Struct aws_sdk_lambda::operation::list_code_signing_configs::builders::ListCodeSigningConfigsInputBuilder
source · #[non_exhaustive]pub struct ListCodeSigningConfigsInputBuilder { /* private fields */ }Expand description
A builder for ListCodeSigningConfigsInput.
Implementations
sourceimpl ListCodeSigningConfigsInputBuilder
impl ListCodeSigningConfigsInputBuilder
sourcepub fn marker(self, input: impl Into<String>) -> Self
pub fn marker(self, input: impl Into<String>) -> Self
Specify the pagination token that's returned by a previous request to retrieve the next page of results.
sourcepub fn set_marker(self, input: Option<String>) -> Self
pub fn set_marker(self, input: Option<String>) -> Self
Specify the pagination token that's returned by a previous request to retrieve the next page of results.
sourcepub fn get_marker(&self) -> &Option<String>
pub fn get_marker(&self) -> &Option<String>
Specify the pagination token that's returned by a previous request to retrieve the next page of results.
sourcepub fn set_max_items(self, input: Option<i32>) -> Self
pub fn set_max_items(self, input: Option<i32>) -> Self
Maximum number of items to return.
sourcepub fn get_max_items(&self) -> &Option<i32>
pub fn get_max_items(&self) -> &Option<i32>
Maximum number of items to return.
sourcepub fn build(self) -> Result<ListCodeSigningConfigsInput, BuildError>
pub fn build(self) -> Result<ListCodeSigningConfigsInput, BuildError>
Consumes the builder and constructs a ListCodeSigningConfigsInput.
sourceimpl ListCodeSigningConfigsInputBuilder
impl ListCodeSigningConfigsInputBuilder
sourcepub async fn send_with(
self,
client: &Client
) -> Result<ListCodeSigningConfigsOutput, SdkError<ListCodeSigningConfigsError, HttpResponse>>
pub async fn send_with( self, client: &Client ) -> Result<ListCodeSigningConfigsOutput, SdkError<ListCodeSigningConfigsError, HttpResponse>>
Sends a request with this input using the given client.